Module common_beam

Module common_beam 

Common beam algorithms.

Two algorithms are provided:

Enums

CommonBeamError

Functions

common_beam
Find the smallest beam that all beams can be convolved to.
common_manybeams_mve
Find common beam using the minimum-volume-enclosing-ellipsoid of sampled beam boundary points (Khachiyan algorithm). Matches radio_beam method='pts'.
find_commonbeam_between
Find the common beam between exactly 2 beams using the CASA analytic method.
fits_in_beam
True if all beams can be deconvolved from large_beam.
largest_beam